@@ -149,6 +149,8 @@ async def serve_page(
         course_name=user.course_name,
         base_course=course_row.base_course,
         user_id=user.username,
+        # _`root_path`: The server is mounted in a different location depending on how it's run (directly from gunicorn/uvicorn or under the ``/ns`` prefix using nginx). Tell the JS what prefix to use for Ajax requests. See also `setting root_path <setting root_path>` and the `FastAPI docs <https://fastapi.tiangolo.com/advanced/behind-a-proxy/>`_. This is then used in the ``eBookConfig`` of :doc:`runestone/common/project_template/_templates/plugin_layouts/sphinx_bootstrap/layout.html`.
+        new_server_prefix=request.scope.get("root_path"),
         # TODO
         user_email="bonelake@mac.com",
         downloads_enabled="false",
@@ -158,14 +160,16 @@ async def serve_page(
         is_logged_in=logged_in,
         is_instructor="true",
         enable_compare_me="true",
-        new_server_prefix="/ns",
         readings=[],
     )
     # See `templates <https://fastapi.tiangolo.com/advanced/templates/>`_.
     try:
         return templates.TemplateResponse(pagepath, context)
     except TemplateNotFound:
-        raise HTTPException(status_code=404, detail="Page not found.")
+        raise HTTPException(
+            status_code=404,
+            detail=f"Page {pagepath} not found in base course {course_row.base_course}.",
+        )
 
 
 # Utilities
